class Node:

    def __init__(self, value):
        self.value = value
        self.next = None

class LinkedList:
    
    def __init__(self):
        self.first = None
        
    def prepend(self, value):
        """Adds a node with the given value to the front of the list."""
        newNode = Node(value)
        newNode.next = self.first
        self.first = newNode
        
    def append(self, value):
        """Adds a node with the given value to the end of the list."""
        if self.first is None:
            self.first = Node(value)
        else:
            current = self.first
            while current.next is not None:
                current = current.next
            current.next = Node(value)

    def contains(self, value):
        """ Determines whether the given value is in the list. """
        current = self.first
        while current is not None:
            if current.value == value:
                return True
            current = current.next
        return False
    
    def asString(self):
        """Returns a string representing the list contents."""
        s = "<"
        if self.first is not None:
            s += str(self.first.value)
            current = self.first.next
            while current is not None:
                s += ", " + str(current.value)
                current = current.next
        s += ">"
        return s
    
    def isEmpty(self):
        """ Returns whether the list is empty."""
        return (self.first is None)

    def length(self):
        """Returns the length of the list."""
        current = self.first
        count = 0
        while current is not None:
            count += 1
            current = current.next
        return count

    def delete(self, value):
        """Deletes the node at the given index."""
        previous = None
        current = self.first
        while current is not None and current.value != value:
            previous = current
            current = current.next
        if current is not None:
            if previous is None:
                self.first = self.first.next
            else:
                previous.next = current.next

    __repr__ = asString
    __str__ = asString
    __contains__ = contains
    __delitem__ = delete
    
